@@ -5,12 +5,11 @@ import ubii.proto as ub
 
 from ubii.framework import debug
 
-pytestmark = pytest.mark.asyncio
 __protobuf__ = ub.__protobuf__
 
 
 class TestBasic:
-    async def test_debug_settings(self, enable_debug):
+    async def test_debug_settings(self, debug_settings):
         assert debug()
 
 
